import Button from "@suid/material/Button";
import { Box, Container, CssBaseline, FormGroup, Input, Paper, Table, TableBody, TableCell, TableContainer, TableHead, TableRow, TextField, Typography } from "@suid/material";

import { createTheme } from "@suid/material";
import { ThemeProvider } from "@suid/material";
import { Accessor, Signal, createEffect, createSignal, onMount } from "solid-js";
import { CheckBox } from "@suid/icons-material";
import { Checkbox } from "@suid/material";

let theme = createTheme({
  palette: {
    mode: "dark",
  },
});

function TodoTable({ todos }: { todos: Accessor<string[]> }) {
  console.log(todos)
  return (
    <TableContainer sx={{ width: "100%", maxWidth: "200px", margin: "0 auto" }} component={Paper}>
      <Table>
        <TableHead>
          <TableRow>
            <TableCell><Typography variant="h6">Done</Typography></TableCell>
            <TableCell><Typography variant="h6">Todos</Typography></TableCell>
          </TableRow>
        </TableHead>
        <TableBody>
          {todos().map((todo) => (
            <TableRow sx={{ "&:hover": { backgroundColor: "#FFFFFF20"}}}>
              <TableCell>
                <Checkbox />
              </TableCell>
              <TableCell>
                <Typography>{todo}</Typography>
              </TableCell>
            </TableRow>
          ))}
        </TableBody>
      </Table>
    </TableContainer>
  )
}

export default function App() {
  const [todos, setTodos] = createSignal([]);
  const [search, setSearch] = createSignal("");

  onMount(() => {
    const todos = localStorage.getItem("todos")
    if (todos) setTodos(JSON.parse(todos))
    console.log(todos)
  })

  createEffect(() => {
    localStorage.setItem("todos", JSON.stringify(todos()))
  })

  return (
    <>
      <CssBaseline />
      <ThemeProvider theme={theme} >
        <Box sx={{ backgroundColor: "background.default", color: "text.primary", margin: "0", minHeight: "100vh", width: "100%" }}>
          <Container maxWidth="sm" disableGutters sx={{ p: 4, display: "flex", flexDirection: "column", alignItems: "center" }}>
            <FormGroup row>
              <TextField label="New Todo" value={search()} variant="outlined" sx={{
                "& fieldset": {
                  borderTopRightRadius: "0",
                  borderBottomRightRadius: "0",
                }
              }} onChange={(e): string => setSearch(e.target.value)} />
              <Button onClick={(e): void => {
                if (search() === "") return
                setTodos(todos().concat(search()))
                setSearch("")
              }} disableElevation variant="contained" sx={{
                borderTopLeftRadius: "0",
                borderBottomLeftRadius: "0",
              }}>Add</Button>
            </FormGroup>
          </Container>
          <TodoTable todos={todos} />
        </Box>
      </ThemeProvider >
    </>
  )
}
